@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2017-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -31,21 +31,19 @@
  *
  */
 
-#include <string.h>
-#include <stdlib.h>
-
-#include "pqos.h"
 #include "api.h"
+
 #include "allocation.h"
+#include "cap.h"
+#include "cpuinfo.h"
+#include "hw_monitoring.h"
+#include "log.h"
+#include "monitoring.h"
 #include "os_allocation.h"
 #include "os_monitoring.h"
-#include "monitoring.h"
-#include "os_monitoring.h"
-#include "hw_monitoring.h"
-#include "cap.h"
-#include "log.h"
-#include "types.h"
-#include "cpuinfo.h"
+
+#include <stdlib.h>
+#include <string.h>
 
 /**
  * Value marking monitoring group structure as "valid".
@@ -78,11 +76,17 @@ static struct pqos_api {
         int (*mon_add_pids)(const unsigned num_pids,
                             const pid_t *pids,
                             struct pqos_mon_data *group);
-        /**  Remove pids from the resource monitoring group */
+        /** Remove pids from the resource monitoring group */
         int (*mon_remove_pids)(const unsigned num_pids,
                                const pid_t *pids,
                                struct pqos_mon_data *group);
-        /*Stops resource monitoring data for selected monitoring group */
+        /** Starts uncore monitoring */
+        int (*mon_start_uncore)(const unsigned num_sockets,
+                                const unsigned *sockets,
+                                const enum pqos_mon_event event,
+                                void *context,
+                                struct pqos_mon_data *group);
+        /** Stops resource monitoring data for selected monitoring group */
         int (*mon_stop)(struct pqos_mon_data *group);
 
         /** Associates lcore with given class of service */
@@ -189,6 +193,7 @@ api_init(int interface, enum pqos_vendor vendor)
                         api.mba_get = hw_mba_get_amd;
                         api.mba_set = hw_mba_set_amd;
                 } else {
+                        api.mon_start_uncore = hw_mon_start_uncore;
                         api.mba_get = hw_mba_get;
                         api.mba_set = hw_mba_set;
                 }
@@ -656,13 +661,17 @@ pqos_mon_start(const unsigned num_cores,
          */
         if (event & (~(PQOS_MON_EVENT_L3_OCCUP | PQOS_MON_EVENT_LMEM_BW |
                        PQOS_MON_EVENT_TMEM_BW | PQOS_MON_EVENT_RMEM_BW |
-                       PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS)))
+                       PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS |
+                       PQOS_PERF_EVENT_LLC_REF)))
                 return PQOS_RETVAL_PARAM;
 
         if ((event & (PQOS_MON_EVENT_L3_OCCUP | PQOS_MON_EVENT_LMEM_BW |
                       PQOS_MON_EVENT_TMEM_BW | PQOS_MON_EVENT_RMEM_BW)) == 0 &&
-            (event & (PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS)) != 0)
+            (event & (PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS |
+                      PQOS_PERF_EVENT_LLC_REF)) != 0) {
+                LOG_ERROR("Only PMU events selected for monitoring\n");
                 return PQOS_RETVAL_PARAM;
+        }
 
         _pqos_api_lock();
 
@@ -703,6 +712,7 @@ int
 pqos_mon_stop(struct pqos_mon_data *group)
 {
         int ret;
+        int manage_memory;
 
         if (group == NULL)
                 return PQOS_RETVAL_PARAM;
@@ -725,9 +735,12 @@ pqos_mon_stop(struct pqos_mon_data *group)
                 ret = PQOS_RETVAL_RESOURCE;
         }
 
+        manage_memory = group->intl->manage_memory;
         free(group->intl);
-        group->intl = NULL;
-        group->valid = 0;
+        if (manage_memory)
+                free(group);
+        else
+                memset(group, 0, sizeof(*group));
 
         _pqos_api_unlock();
 
@@ -805,13 +818,17 @@ pqos_mon_start_pids(const unsigned num_pids,
          */
         if (event & (~(PQOS_MON_EVENT_L3_OCCUP | PQOS_MON_EVENT_LMEM_BW |
                        PQOS_MON_EVENT_TMEM_BW | PQOS_MON_EVENT_RMEM_BW |
-                       PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS)))
+                       PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS |
+                       PQOS_PERF_EVENT_LLC_REF)))
                 return PQOS_RETVAL_PARAM;
 
         if ((event & (PQOS_MON_EVENT_L3_OCCUP | PQOS_MON_EVENT_LMEM_BW |
                       PQOS_MON_EVENT_TMEM_BW | PQOS_MON_EVENT_RMEM_BW)) == 0 &&
-            (event & (PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS)) != 0)
+            (event & (PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS |
+                      PQOS_PERF_EVENT_LLC_REF)) != 0) {
+                LOG_ERROR("Only PMU events selected for monitoring\n");
                 return PQOS_RETVAL_PARAM;
+        }
 
         _pqos_api_lock();
 
@@ -874,3 +891,196 @@ pqos_mon_remove_pids(const unsigned num_pids,
 
         return API_CALL(mon_remove_pids, num_pids, pids, group);
 }
+
+int
+pqos_mon_start_uncore(const unsigned num_sockets,
+                      const unsigned *sockets,
+                      const enum pqos_mon_event event,
+                      void *context,
+                      struct pqos_mon_data **group)
+{
+        int ret;
+        struct pqos_mon_data *data = NULL;
+
+        if (num_sockets == 0 || sockets == NULL || group == NULL || event == 0)
+                return PQOS_RETVAL_PARAM;
+
+        /**
+         * Validate event parameter
+         */
+        if ((event & (PQOS_PERF_EVENT_LLC_MISS_PCIE_READ |
+                      PQOS_PERF_EVENT_LLC_MISS_PCIE_WRITE |
+                      PQOS_PERF_EVENT_LLC_REF_PCIE_READ |
+                      PQOS_PERF_EVENT_LLC_REF_PCIE_WRITE)) == 0)
+                return PQOS_RETVAL_PARAM;
+
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
+        data = calloc(1, sizeof(*data));
+        if (data == NULL) {
+                ret = PQOS_RETVAL_RESOURCE;
+                goto pqos_mon_start_uncore_exit;
+        }
+
+        data->intl = calloc(1, sizeof(*data->intl));
+        if (data->intl == NULL) {
+                ret = PQOS_RETVAL_RESOURCE;
+                goto pqos_mon_start_uncore_exit;
+        }
+        data->intl->manage_memory = 1;
+
+        if (api.mon_start_uncore != NULL)
+                ret = api.mon_start_uncore(num_sockets, sockets, event, context,
+                                           data);
+        else {
+                LOG_INFO(UNSUPPORTED_INTERFACE);
+                ret = PQOS_RETVAL_RESOURCE;
+        }
+
+pqos_mon_start_uncore_exit:
+        if (ret == PQOS_RETVAL_OK) {
+                data->valid = GROUP_VALID_MARKER;
+                *group = data;
+        } else if (data != NULL) {
+                free(data->intl);
+                free(data);
+        }
+
+        _pqos_api_unlock();
+
+        return ret;
+}
+
+int
+pqos_mon_get_value(const struct pqos_mon_data *const group,
+                   const enum pqos_mon_event event_id,
+                   uint64_t *value,
+                   uint64_t *delta)
+{
+        int ret;
+        uint64_t _value;
+        uint64_t _delta;
+
+        if (event_id == PQOS_PERF_EVENT_IPC) {
+                LOG_ERROR("PQOS_PERF_EVENT_IPC is unsupported, please use "
+                          "pqos_mon_get_ipc function");
+                return PQOS_RETVAL_PARAM;
+        }
+
+        if (group == NULL)
+                return PQOS_RETVAL_PARAM;
+
+        if (group->valid != GROUP_VALID_MARKER)
+                return PQOS_RETVAL_PARAM;
+
+        if ((group->event & event_id) == 0)
+                return PQOS_RETVAL_PARAM;
+
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
+        switch (event_id) {
+        case PQOS_MON_EVENT_L3_OCCUP:
+                if (delta != NULL)
+                        LOG_WARN("Counter delta is undefined for "
+                                 "PQOS_MON_EVENT_L3_OCCUP\n");
+                _value = group->values.llc;
+                _delta = 0;
+                break;
+        case PQOS_MON_EVENT_LMEM_BW:
+                _value = group->values.mbm_local;
+                _delta = group->values.mbm_local_delta;
+                break;
+        case PQOS_MON_EVENT_TMEM_BW:
+                _value = group->values.mbm_total;
+                _delta = group->values.mbm_total_delta;
+                break;
+        case PQOS_MON_EVENT_RMEM_BW:
+                _value = group->values.mbm_remote;
+                _delta = group->values.mbm_remote_delta;
+                break;
+        case PQOS_PERF_EVENT_LLC_MISS:
+                _value = group->values.llc_misses;
+                _delta = group->values.llc_misses_delta;
+                break;
+        case PQOS_PERF_EVENT_LLC_REF:
+#if PQOS_VERSION >= 50000
+                _value = group->values.llc_references;
+                _delta = group->values.llc_references_delta;
+#else
+                _value = group->intl->values.llc_references;
+                _delta = group->intl->values.llc_references_delta;
+#endif
+                break;
+        case PQOS_PERF_EVENT_LLC_MISS_PCIE_READ:
+                _value = group->intl->values.pcie.llc_misses.read;
+                _delta = group->intl->values.pcie.llc_misses.read_delta;
+                break;
+        case PQOS_PERF_EVENT_LLC_MISS_PCIE_WRITE:
+                _value = group->intl->values.pcie.llc_misses.write;
+                _delta = group->intl->values.pcie.llc_misses.write_delta;
+                break;
+        case PQOS_PERF_EVENT_LLC_REF_PCIE_READ:
+                _value = group->intl->values.pcie.llc_references.read;
+                _delta = group->intl->values.pcie.llc_references.read_delta;
+                break;
+        case PQOS_PERF_EVENT_LLC_REF_PCIE_WRITE:
+                _value = group->intl->values.pcie.llc_references.write;
+                _delta = group->intl->values.pcie.llc_references.write_delta;
+                break;
+        default:
+                LOG_ERROR("Unknown event %x\n", event_id);
+                ret = PQOS_RETVAL_PARAM;
+        }
+
+        if (ret == PQOS_RETVAL_OK) {
+                if (value != NULL)
+                        *value = _value;
+                if (delta != NULL)
+                        *delta = _delta;
+        }
+
+        _pqos_api_unlock();
+
+        return ret;
+}
+
+int
+pqos_mon_get_ipc(const struct pqos_mon_data *const group, double *value)
+{
+        int ret;
+
+        if (group == NULL || value == NULL)
+                return PQOS_RETVAL_PARAM;
+
+        if (group->valid != GROUP_VALID_MARKER)
+                return PQOS_RETVAL_PARAM;
+
+        if ((group->event & PQOS_PERF_EVENT_IPC) == 0)
+                return PQOS_RETVAL_PARAM;
+
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
+        *value = group->values.ipc;
+
+        _pqos_api_unlock();
+
+        return ret;
+}
