@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -35,31 +35,29 @@
  * @brief CPU sockets and cores enumeration module.
  */
 
-#include <string.h>
-#include <stdint.h>
-#include <limits.h>
+#include "cpuinfo.h"
+
+#include "allocation.h"
+#include "cap.h"
+#include "cpu_registers.h"
+#include "log.h"
+#include "machine.h"
+#include "os_allocation.h"
+#include "os_cpuinfo.h"
+
 #include <errno.h>
+#include <limits.h>
+#include <stdint.h>
+#include <string.h>
 #include <unistd.h> /* sysconf() */
 #ifdef __FreeBSD__
-#include <sys/param.h>  /* sched affinity */
 #include <sys/cpuset.h> /* sched affinity */
+#include <sys/param.h>  /* sched affinity */
 #endif
 #ifdef __linux__
 #include <sched.h> /* sched affinity */
 #endif
 
-#include "pqos.h"
-
-#include "cpu_registers.h"
-#include "log.h"
-#include "cpuinfo.h"
-#include "types.h"
-#include "machine.h"
-#include "os_allocation.h"
-#include "allocation.h"
-#include "cap.h"
-#include "os_cpuinfo.h"
-
 /**
  * This structure will be made externally available
  * If not NULL then module is initialized.
@@ -110,13 +108,14 @@ static int
 set_affinity_mask(const cpu_set_t *p_set)
 {
         if (p_set == NULL)
-                return -EFAULT;
-#ifdef __linux__
+                return -EINVAL;
+#if defined(__linux__)
         return sched_setaffinity(0, sizeof(*p_set), p_set);
-#endif
-#ifdef __FreeBSD__
+#elif defined(__FreeBSD__)
         return cpuset_setaffinity(CPU_LEVEL_WHICH, CPU_WHICH_TID, -1,
                                   sizeof(*p_set), p_set);
+#else
+        return -EFAULT;
 #endif
 }
 
