@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2017-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -31,27 +31,26 @@
  *
  */
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <string.h>
-#include <stdio.h>
-#include <ctype.h>
-#include <stdlib.h>
-#include <errno.h>
-#include <dirent.h> /**< scandir() */
-
-#include "pqos.h"
-#include "allocation.h"
 #include "os_allocation.h"
+
+#include "allocation.h"
 #include "cap.h"
 #include "common.h"
+#include "cpuinfo.h"
 #include "log.h"
-#include "types.h"
 #include "resctrl.h"
 #include "resctrl_alloc.h"
 #include "resctrl_monitoring.h"
 #include "resctrl_utils.h"
-#include "cpuinfo.h"
+
+#include <ctype.h>
+#include <dirent.h> /**< scandir() */
+#include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
 int
 os_alloc_mount(const enum pqos_cdp_config l3_cdp_cfg,
@@ -62,8 +61,8 @@ os_alloc_mount(const enum pqos_cdp_config l3_cdp_cfg,
         const struct pqos_cap_l2ca *l2_cap = NULL;
         const struct pqos_cap_mba *mba_cap = NULL;
         const struct pqos_capability *alloc_cap = NULL;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
         const struct cpuinfo_config *vconfig;
         int ret;
 
@@ -84,7 +83,6 @@ os_alloc_mount(const enum pqos_cdp_config l3_cdp_cfg,
                 return PQOS_RETVAL_PARAM;
         }
 
-        _pqos_cap_get(&cap, &cpu);
         cpuinfo_get_config(&vconfig);
 
         if (l3_cdp_cfg == PQOS_REQUIRE_CDP_OFF &&
@@ -229,11 +227,9 @@ static int
 os_alloc_prep(void)
 {
         unsigned i, num_grps = 0;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
         int ret;
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_alloc_get_grps_num(cap, &num_grps);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -298,10 +294,8 @@ os_alloc_assoc_set(const unsigned lcore, const unsigned class_id)
         unsigned grps;
         int ret_mon;
         char mon_group[256];
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
-
-        _pqos_cap_get(&cap, &cpu);
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         ret = pqos_cpu_check_core(cpu, lcore);
         if (ret != PQOS_RETVAL_OK)
@@ -352,12 +346,10 @@ int
 os_alloc_assoc_get(const unsigned lcore, unsigned *class_id)
 {
         int ret;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         ASSERT(class_id != NULL);
 
-        _pqos_cap_get(NULL, &cpu);
-
         ret = pqos_cpu_check_core(cpu, lcore);
         if (ret != PQOS_RETVAL_OK)
                 return PQOS_RETVAL_PARAM;
@@ -379,12 +371,10 @@ os_pid_get_pid_assoc(const unsigned class_id, unsigned *count)
         unsigned grps;
         int ret;
         unsigned *tasks;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(count != NULL);
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_alloc_get_grps_num(cap, &grps);
         if (ret != PQOS_RETVAL_OK)
                 return NULL;
@@ -412,15 +402,13 @@ os_alloc_assign(const unsigned technology,
 {
         unsigned i, num_rctl_grps = 0;
         int ret;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(core_num > 0);
         ASSERT(core_array != NULL);
         ASSERT(class_id != NULL);
         UNUSED_PARAM(technology);
 
-        _pqos_cap_get(&cap, NULL);
-
         /* obtain highest class id for all requested technologies */
         ret = resctrl_alloc_get_grps_num(cap, &num_rctl_grps);
         if (ret != PQOS_RETVAL_OK)
@@ -450,12 +438,10 @@ os_alloc_release(const unsigned *core_array, const unsigned core_num)
         int ret;
         unsigned i, cos0 = 0;
         struct resctrl_cpumask mask;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         ASSERT(core_num > 0 && core_array != NULL);
 
-        _pqos_cap_get(NULL, &cpu);
-
         ret = resctrl_lock_exclusive();
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -491,9 +477,7 @@ os_alloc_reset_cores(void)
         struct resctrl_cpumask mask;
         unsigned i;
         int ret;
-        const struct pqos_cpuinfo *cpu;
-
-        _pqos_cap_get(NULL, &cpu);
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         LOG_INFO("OS alloc reset - core assoc\n");
 
@@ -519,13 +503,11 @@ os_alloc_reset_schematas(const struct pqos_cap_l3ca *l3_cap,
         unsigned grps;
         unsigned i;
         int ret;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         LOG_INFO("OS alloc reset - schematas\n");
 
-        _pqos_cap_get(&cap, &cpu);
-
         ret = resctrl_lock_exclusive();
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -851,12 +833,14 @@ os_alloc_reset_full(const enum pqos_cdp_config l3_cdp_cfg,
                 LOG_ERROR("Mount OS interface error!\n");
                 goto os_alloc_reset_full_exit;
         }
+
         if (l3_cap != NULL)
                 _pqos_cap_l3cdp_change(l3_cdp_cfg);
         if (l2_cap != NULL)
                 _pqos_cap_l2cdp_change(l2_cdp_cfg);
         if (mba_cap != NULL)
                 _pqos_cap_mba_change(mba_cfg);
+
         /**
          * Create the COS dir's in resctrl.
          */
@@ -885,7 +869,7 @@ os_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
         int l2_cdp_changed = 0;
         int mba_changed = 0;
         int ret;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(l3_cdp_cfg == PQOS_REQUIRE_CDP_ON ||
                l3_cdp_cfg == PQOS_REQUIRE_CDP_OFF ||
@@ -898,8 +882,6 @@ os_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
         ASSERT(mba_cfg == PQOS_MBA_DEFAULT || mba_cfg == PQOS_MBA_CTRL ||
                mba_cfg == PQOS_MBA_ANY);
 
-        _pqos_cap_get(&cap, NULL);
-
         /* Get L3 CAT capabilities */
         (void)pqos_cap_get_type(cap, PQOS_CAP_TYPE_L3CA, &alloc_cap);
         if (alloc_cap != NULL)
@@ -1075,14 +1057,12 @@ os_l3ca_set(const unsigned l3cat_id,
         unsigned i;
         unsigned num_grps = 0, l3ca_num;
         int cdp_enabled = 0;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         ASSERT(ca != NULL);
         ASSERT(num_cos != 0);
 
-        _pqos_cap_get(&cap, &cpu);
-
         ret = pqos_l3ca_get_cos_num(cap, &l3ca_num);
         if (ret != PQOS_RETVAL_OK)
                 return PQOS_RETVAL_RESOURCE; /* L3 CAT not supported */
@@ -1166,15 +1146,13 @@ os_l3ca_get(const unsigned l3cat_id,
         int ret;
         unsigned class_id;
         unsigned count = 0;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         ASSERT(num_ca != NULL);
         ASSERT(ca != NULL);
         ASSERT(max_num_ca != 0);
 
-        _pqos_cap_get(&cap, &cpu);
-
         ret = pqos_l3ca_get_cos_num(cap, &count);
         if (ret != PQOS_RETVAL_OK)
                 return PQOS_RETVAL_RESOURCE; /* L3 CAT not supported */
@@ -1231,12 +1209,10 @@ os_l3ca_get_min_cbm_bits(unsigned *min_cbm_bits)
         char buf[128];
         const struct pqos_capability *l3_cap = NULL;
         uint64_t value;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(min_cbm_bits != NULL);
 
-        _pqos_cap_get(&cap, NULL);
-
         /**
          * Get L3 CAT capabilities
          */
@@ -1296,14 +1272,12 @@ os_l2ca_set(const unsigned l2id,
         unsigned i;
         unsigned num_grps = 0, l2ca_num;
         int cdp_enabled;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         ASSERT(ca != NULL);
         ASSERT(num_cos != 0);
 
-        _pqos_cap_get(&cap, &cpu);
-
         ret = pqos_l2ca_get_cos_num(cap, &l2ca_num);
         if (ret != PQOS_RETVAL_OK)
                 return PQOS_RETVAL_RESOURCE; /* L2 CAT not supported */
@@ -1397,15 +1371,13 @@ os_l2ca_get(const unsigned l2id,
         int ret;
         unsigned class_id;
         unsigned count = 0;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         ASSERT(num_ca != NULL);
         ASSERT(ca != NULL);
         ASSERT(max_num_ca != 0);
 
-        _pqos_cap_get(&cap, &cpu);
-
         ret = pqos_l2ca_get_cos_num(cap, &count);
         if (ret != PQOS_RETVAL_OK)
                 return PQOS_RETVAL_RESOURCE; /* L2 CAT not supported */
@@ -1462,13 +1434,11 @@ os_l2ca_get_min_cbm_bits(unsigned *min_cbm_bits)
         int ret;
         char buf[128];
         const struct pqos_capability *l2_cap = NULL;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
         uint64_t value;
 
         ASSERT(min_cbm_bits != NULL);
 
-        _pqos_cap_get(&cap, NULL);
-
         /**
          * Get L2 CAT capabilities
          */
@@ -1495,15 +1465,13 @@ os_mba_set(const unsigned mba_id,
         int ret;
         unsigned i, step = 0;
         unsigned num_grps = 0;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
         const struct pqos_capability *mba_cap = NULL;
 
         ASSERT(requested != NULL);
         ASSERT(num_cos != 0);
 
-        _pqos_cap_get(&cap, &cpu);
-
         /**
          * Check if MBA is supported
          */
@@ -1623,15 +1591,13 @@ os_mba_set_amd(const unsigned mba_id,
         int ret;
         unsigned i;
         unsigned num_grps = 0;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
         const struct pqos_capability *mba_cap = NULL;
 
         ASSERT(requested != NULL);
         ASSERT(num_cos != 0);
 
-        _pqos_cap_get(&cap, &cpu);
-
         /**
          * Check if MBA is supported
          */
@@ -1737,16 +1703,14 @@ os_mba_get(const unsigned mba_id,
         int ret;
         unsigned class_id;
         unsigned count = 0;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
         const struct pqos_capability *mba_cap = NULL;
 
         ASSERT(num_cos != NULL);
         ASSERT(max_num_cos != 0);
         ASSERT(mba_tab != NULL);
 
-        _pqos_cap_get(&cap, &cpu);
-
         /**
          * Check if MBA is supported
          */
@@ -1808,16 +1772,14 @@ os_mba_get_amd(const unsigned mba_id,
         int ret;
         unsigned class_id;
         unsigned count = 0;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
         const struct pqos_capability *mba_cap = NULL;
 
         ASSERT(num_cos != NULL);
         ASSERT(max_num_cos != 0);
         ASSERT(mba_tab != NULL);
 
-        _pqos_cap_get(&cap, &cpu);
-
         /**
          * Check if MBA is supported
          */
@@ -1877,9 +1839,7 @@ os_alloc_assoc_set_pid(const pid_t task, const unsigned class_id)
         unsigned max_cos = 0;
         int ret_mon;
         char mon_group[256];
-        const struct pqos_cap *cap;
-
-        _pqos_cap_get(&cap, NULL);
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         /* Get number of COS */
         ret = resctrl_alloc_get_grps_num(cap, &max_cos);
@@ -1952,15 +1912,13 @@ os_alloc_assign_pid(const unsigned technology,
 {
         unsigned i, num_rctl_grps = 0;
         int ret;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(task_num > 0);
         ASSERT(task_array != NULL);
         ASSERT(class_id != NULL);
         UNUSED_PARAM(technology);
 
-        _pqos_cap_get(&cap, NULL);
-
         /* obtain highest class id for all requested technologies */
         ret = resctrl_alloc_get_grps_num(cap, &num_rctl_grps);
         if (ret != PQOS_RETVAL_OK)
