@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -41,10 +41,10 @@
 #ifndef __PQOS_H__
 #define __PQOS_H__
 
+#include <math.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <unistd.h>
-#include <math.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -56,8 +56,8 @@ extern "C" {
  * =======================================
  */
 
-#define PQOS_VERSION      40300 /**< version 4.3.0 */
-#define PQOS_MAX_COS      16    /** 16 x COS */
+#define PQOS_VERSION      40401 /**< version 4.4.1 */
+#define PQOS_MAX_COS      16    /**< 16 x COS */
 #define PQOS_MAX_L3CA_COS PQOS_MAX_COS
 #define PQOS_MAX_L2CA_COS PQOS_MAX_COS
 
@@ -278,6 +278,16 @@ enum pqos_mon_event {
         RESERVED2 = 0x2000,
         PQOS_PERF_EVENT_LLC_MISS = 0x4000, /**< LLC misses */
         PQOS_PERF_EVENT_IPC = 0x8000,      /**< instructions per clock */
+        PQOS_PERF_EVENT_LLC_REF = 0x10000, /**< LLC references */
+
+        PQOS_PERF_EVENT_LLC_MISS_PCIE_READ =
+            0x100000, /**< DDIO LLC read misses */
+        PQOS_PERF_EVENT_LLC_MISS_PCIE_WRITE =
+            0x200000, /**< DDIO LLC write misses */
+        PQOS_PERF_EVENT_LLC_REF_PCIE_READ =
+            0x400000, /**< DDIO LLC read references */
+        PQOS_PERF_EVENT_LLC_REF_PCIE_WRITE =
+            0x800000, /**< DDIO LLC write references */
 };
 
 /**
@@ -357,9 +367,7 @@ struct pqos_cacheinfo {
 };
 
 /**
- * =======================================
  * Vendor values
- * =======================================
  */
 enum pqos_vendor {
         PQOS_VENDOR_UNKNOWN = 0, /**< UNKNOWN */
@@ -428,6 +436,10 @@ struct pqos_event_values {
         double ipc;                  /**< retired instructions / cycles */
         uint64_t llc_misses;         /**< LLC misses - reading */
         uint64_t llc_misses_delta;   /**< LLC misses - delta */
+#if PQOS_VERSION >= 50000
+        uint64_t llc_references;       /**< LLC references - reading */
+        uint64_t llc_references_delta; /**< LLC references - delta */
+#endif
 };
 
 struct pqos_mon_data_internal;
@@ -573,6 +585,25 @@ int pqos_mon_remove_pids(const unsigned num_pids,
                          const pid_t *pids,
                          struct pqos_mon_data *group);
 
+/**
+ * @brief Starts uncore monitoring of selected \a sockets
+ *
+ * @param [in] num_sockets number of sockets in \a sockets array
+ * @param [in] sockets array of socket IDs
+ * @param [in] event monitoring event id
+ * @param [in] context a pointer for application's convenience
+ *             (unused by the library)
+ * @param [out] group a pointer to monitoring structure
+ *
+ * @return Operations status
+ * @retval PQOS_RETVAL_OK on success
+ */
+int pqos_mon_start_uncore(const unsigned num_sockets,
+                          const unsigned *sockets,
+                          const enum pqos_mon_event event,
+                          void *context,
+                          struct pqos_mon_data **group);
+
 /**
  * @brief Stops resource monitoring data for selected monitoring group
  *
@@ -586,7 +617,7 @@ int pqos_mon_stop(struct pqos_mon_data *group);
 /**
  * @brief Polls monitoring data from requested cores
  *
- * @param [in] groups table of monitoring group pointers to be be updated
+ * @param [in] groups table of monitoring group pointers to be updated
  * @param [in] num_groups number of monitoring groups in the table
  *
  * @return Operations status
@@ -1250,15 +1281,23 @@ int pqos_mba_ctrl_enabled(const struct pqos_cap *cap,
  */
 enum pqos_vendor pqos_get_vendor(const struct pqos_cpuinfo *cpu);
 
+#if PQOS_VERSION < 50000
 /**
  * @brief Retrieves a monitoring value from a group for a specific event.
  * @param [out] value monitoring value
  * @param [in] event_id event being monitored
  * @param [in] group monitoring group
  *
+ * @deprecated Will be removed in 5.0.0 release
+ * @see pqos_mon_get_value
+ * @see pqos_mon_get_ipc
+ *
  * @return Operation status
  * @retval PQOS_RETVAL_OK on success
  */
+#if !defined(SWIG) && !defined(SWIGPERL)
+__attribute__((deprecated))
+#endif
 static inline int
 pqos_mon_get_event_value(void *const value,
                          const enum pqos_mon_event event_id,
@@ -1295,6 +1334,38 @@ pqos_mon_get_event_value(void *const value,
 
         return PQOS_RETVAL_OK;
 }
+#endif
+
+/*
+ * @brief Retrieves a monitoring value from a group for a specific event.
+ *
+ * @note Update event values using \a pqos_mon_poll
+ *
+ * @param [in] group monitoring group
+ * @param [in] event_id event being monitored
+ * @param [out] value monitoring counter value
+ * @param [out] delta monitoring counter delta
+ *
+ * @return Operation status
+ * @retval PQOS_RETVAL_OK on success
+ */
+int pqos_mon_get_value(const struct pqos_mon_data *const group,
+                       const enum pqos_mon_event event_id,
+                       uint64_t *value,
+                       uint64_t *delta);
+
+/*
+ * @brief Retrieves a IPC value from a monitoring group.
+ *
+ * @note Update event values using \a pqos_mon_poll
+ *
+ * @param [in] group monitoring group
+ * @param [out] value IPC value
+ *
+ * @return Operation status
+ * @retval PQOS_RETVAL_OK on success
+ */
+int pqos_mon_get_ipc(const struct pqos_mon_data *const group, double *value);
 
 #ifdef __cplusplus
 }
