@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2018-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2018-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -31,25 +31,23 @@
  *
  */
 
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <sys/stat.h>
-#include <dirent.h>
-#include <string.h>
-#include <time.h>
-#include <errno.h>
+#include "resctrl_monitoring.h"
 
-#include "pqos.h"
-#include "log.h"
-#include "types.h"
 #include "cap.h"
 #include "common.h"
+#include "log.h"
 #include "monitoring.h"
 #include "resctrl.h"
-#include "resctrl_monitoring.h"
 #include "resctrl_alloc.h"
 
+#include <dirent.h>
+#include <errno.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <time.h>
+#include <unistd.h>
+
 #define GROUP_NAME_PREFIX "pqos-"
 
 /**
@@ -182,12 +180,10 @@ alloc_assoc_get(const unsigned lcore, unsigned *class_id)
 {
         int ret;
         unsigned max_cos;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(class_id != NULL);
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_alloc_get_grps_num(cap, &max_cos);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -218,12 +214,10 @@ alloc_assoc_get_pid(const pid_t tid, unsigned *class_id)
 {
         int ret;
         unsigned max_cos;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(class_id != NULL);
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_alloc_get_grps_num(cap, &max_cos);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -670,14 +664,17 @@ resctrl_mon_assoc_get(const unsigned lcore,
 
         for (i = 0; i < num_groups; i++) {
                 struct resctrl_cpumask mask;
+                const char *d_name = namelist[i]->d_name;
 
-                ret = resctrl_mon_cpumask_read(class_id, namelist[i]->d_name,
-                                               &mask);
+                if (d_name == NULL)
+                        continue;
+
+                ret = resctrl_mon_cpumask_read(class_id, d_name, &mask);
                 if (ret != PQOS_RETVAL_OK)
                         goto resctrl_mon_assoc_get_exit;
 
                 if (resctrl_cpumask_get(lcore, &mask)) {
-                        strncpy(name, namelist[i]->d_name, name_size);
+                        strncpy(name, d_name, name_size);
                         ret = PQOS_RETVAL_OK;
                         goto resctrl_mon_assoc_get_exit;
                 }
@@ -799,9 +796,13 @@ resctrl_mon_assoc_get_pid(const pid_t task,
                 char path[256];
                 char buf[128];
                 FILE *fd;
+                const char *d_name = namelist[i]->d_name;
 
-                resctrl_mon_group_path(class_id, namelist[i]->d_name, "/tasks",
-                                       path, sizeof(path));
+                if (d_name == NULL)
+                        continue;
+
+                resctrl_mon_group_path(class_id, d_name, "/tasks", path,
+                                       sizeof(path));
 
                 fd = pqos_fopen(path, "r");
                 if (fd == NULL)
@@ -819,7 +820,7 @@ resctrl_mon_assoc_get_pid(const pid_t task,
                         }
 
                         if (value == task) {
-                                strncpy(name, namelist[i]->d_name, name_size);
+                                strncpy(name, d_name, name_size);
                                 ret = PQOS_RETVAL_OK;
                                 fclose(fd);
                                 goto resctrl_mon_assoc_get_pid_exit;
@@ -898,15 +899,13 @@ resctrl_mon_parse(struct resctrl_core_group **cgrp, unsigned *cgrp_num)
         int ret = PQOS_RETVAL_OK;
         unsigned cos = 0;
         unsigned ctrl_grps;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
         const struct pqos_capability *cap_mon;
         struct resctrl_core_group *grps = NULL;
         unsigned grps_num = 0;
         unsigned grps_size;
 
-        _pqos_cap_get(&cap, &cpu);
-
         ret = pqos_cap_get_type(cap, PQOS_CAP_TYPE_MON, &cap_mon);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -1041,13 +1040,11 @@ resctrl_mon_assign(struct pqos_mon_data *group)
                 unsigned i;
                 unsigned l3ids = 0;
                 unsigned cgrp_num;
-                const struct pqos_cpuinfo *cpu;
-                const struct pqos_cap *cap;
+                const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
+                const struct pqos_cap *cap = _pqos_get_cap();
                 unsigned max_threshold_occupancy;
                 unsigned max_cos;
 
-                _pqos_cap_get(&cap, &cpu);
-
                 /* list L3IDs for requested cores */
                 for (i = 0; i < group->num_cores; i++) {
                         const struct pqos_coreinfo *coreinfo =
@@ -1153,14 +1150,12 @@ resctrl_mon_start(struct pqos_mon_data *group)
         char *resctrl_group = NULL;
         int ret = PQOS_RETVAL_OK;
         unsigned i;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
         ASSERT(group != NULL);
         ASSERT(group->tid_nr == 0 || group->tid_map != NULL);
         ASSERT(group->num_cores == 0 || group->cores != NULL);
 
-        _pqos_cap_get(NULL, &cpu);
-
         /* List l3ids */
         for (i = 0; i < group->num_cores; i++) {
                 struct pqos_mon_data_internal *intl = group->intl;
@@ -1244,9 +1239,7 @@ resctrl_mon_delete(const char *resctrl_group)
         int ret;
         unsigned max_cos;
         unsigned cos = 0;
-        const struct pqos_cap *cap;
-
-        _pqos_cap_get(&cap, NULL);
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ret = resctrl_alloc_get_grps_num(cap, &max_cos);
         if (ret != PQOS_RETVAL_OK)
@@ -1285,8 +1278,8 @@ resctrl_mon_shared(struct pqos_mon_data *group, unsigned *shared)
         unsigned max_cos;
         unsigned cos;
         int ret;
-        const struct pqos_cap *cap;
-        const struct pqos_cpuinfo *cpu;
+        const struct pqos_cap *cap = _pqos_get_cap();
+        const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
         const char *mon_group = group->intl->resctrl.mon_group;
 
         *shared = 0;
@@ -1294,8 +1287,6 @@ resctrl_mon_shared(struct pqos_mon_data *group, unsigned *shared)
         if (group->num_pids > 0)
                 return PQOS_RETVAL_OK;
 
-        _pqos_cap_get(&cap, &cpu);
-
         ret = resctrl_alloc_get_grps_num(cap, &max_cos);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -1356,12 +1347,10 @@ resctrl_mon_stop(struct pqos_mon_data *group)
         int ret;
         unsigned max_cos;
         unsigned i;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(group != NULL);
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_alloc_get_grps_num(cap, &max_cos);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -1438,6 +1427,9 @@ resctrl_mon_stop(struct pqos_mon_data *group)
                 group->intl->resctrl.mon_group = NULL;
         }
 
+        if (group->intl->resctrl.l3id != NULL)
+                free(group->intl->resctrl.l3id);
+
 resctrl_mon_stop_exit:
         return ret;
 }
@@ -1476,12 +1468,10 @@ resctrl_mon_purge(struct pqos_mon_data *group)
         unsigned cos;
         int ret;
         unsigned shared;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(group != NULL);
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_mon_shared(group, &shared);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -1570,12 +1560,10 @@ resctrl_mon_poll(struct pqos_mon_data *group, const enum pqos_mon_event event)
         unsigned cos;
         unsigned i;
         uint64_t old_value;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         ASSERT(group != NULL);
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_alloc_get_grps_num(cap, &max_cos);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -1658,13 +1646,11 @@ resctrl_mon_reset(void)
         unsigned grps;
         int num_groups;
         unsigned cos = 0;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         if (supported_events == 0)
                 return PQOS_RETVAL_RESOURCE;
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_alloc_get_grps_num(cap, &grps);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
@@ -1714,15 +1700,13 @@ resctrl_mon_active(unsigned *monitoring_status)
         unsigned group_idx = 0;
         unsigned resctrl_group_count = 0;
         int ret;
-        const struct pqos_cap *cap;
+        const struct pqos_cap *cap = _pqos_get_cap();
 
         if (supported_events == 0) {
                 *monitoring_status = 0;
                 return PQOS_RETVAL_OK;
         }
 
-        _pqos_cap_get(&cap, NULL);
-
         ret = resctrl_alloc_get_grps_num(cap, &resctrl_group_count);
         if (ret != PQOS_RETVAL_OK) {
                 LOG_ERROR("Failed to count resctrl groups");
