@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,20 +30,12 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
-#include "test.h"
+#include "cpu_registers.h"
+#include "hw_monitoring.h"
 #include "mock_cap.h"
 #include "mock_perf_monitoring.h"
-
 #include "perf_monitoring.h"
-#include "hw_monitoring.h"
-#include "cpu_registers.h"
+#include "test.h"
 
 /* ======== init ======== */
 
@@ -121,7 +113,7 @@ hw_mon_start_perf(struct pqos_mon_data *group, enum pqos_mon_event event)
 
         group->intl->perf.event =
             event & (PQOS_PERF_EVENT_CYCLES | PQOS_PERF_EVENT_INSTRUCTIONS |
-                     PQOS_PERF_EVENT_LLC_MISS);
+                     PQOS_PERF_EVENT_LLC_MISS | PQOS_PERF_EVENT_LLC_REF);
 
         return mock_type(int);
 }
@@ -176,7 +168,8 @@ test_hw_mon_assoc_get(void **state)
         pqos_rmid_t rmid = 1;
         unsigned lcore = 2;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         expect_value(hw_mon_assoc_read, lcore, lcore);
         will_return(hw_mon_assoc_read, 2);
@@ -195,7 +188,8 @@ test_hw_mon_assoc_get_param(void **state)
         pqos_rmid_t rmid = 1;
         unsigned lcore = 2;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         ret = hw_mon_assoc_get(200, &rmid);
         assert_int_equal(ret, PQOS_RETVAL_PARAM);
@@ -215,7 +209,8 @@ test_hw_mon_reset(void **state)
         int ret;
         unsigned i;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         for (i = 0; i < cpu->num_cores; ++i)
                 expect_value(hw_mon_assoc_write, lcore, cpu->cores[i].lcore);
@@ -234,7 +229,8 @@ test_hw_mon_reset_error(void **state)
         int ret;
         unsigned i;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         for (i = 0; i < cpu->num_cores; ++i)
                 expect_value(hw_mon_assoc_write, lcore, cpu->cores[i].lcore);
@@ -265,8 +261,8 @@ test_hw_mon_start_mbm(void **state)
         group.intl = &intl;
         memset(&intl, 0, sizeof(struct pqos_mon_data_internal));
 
-        will_return(__wrap__pqos_cap_get, data->cap);
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         expect_any(hw_mon_start_perf, event);
         will_return(hw_mon_start_perf, PQOS_RETVAL_OK);
@@ -283,7 +279,6 @@ test_hw_mon_start_mbm(void **state)
         assert_int_equal(group.num_cores, num_cores);
 
         /* free memory */
-        will_return(__wrap__pqos_cap_get, data->cpu);
         expect_value(hw_mon_assoc_read, lcore, cores[0]);
         will_return(hw_mon_assoc_read, 1);
         will_return(hw_mon_assoc_read, PQOS_RETVAL_OK);
@@ -312,8 +307,8 @@ test_hw_mon_start_perf(void **state)
         group.intl = &intl;
         memset(&intl, 0, sizeof(struct pqos_mon_data_internal));
 
-        will_return(__wrap__pqos_cap_get, data->cap);
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         expect_value(hw_mon_assoc_read, lcore, cores[0]);
         will_return(hw_mon_assoc_read, 0);
@@ -334,7 +329,6 @@ test_hw_mon_start_perf(void **state)
         assert_int_equal(group.num_cores, num_cores);
 
         /* free memory */
-        will_return(__wrap__pqos_cap_get, data->cpu);
         expect_value(hw_mon_assoc_read, lcore, cores[0]);
         will_return(hw_mon_assoc_read, 1);
         will_return(hw_mon_assoc_read, PQOS_RETVAL_OK);
@@ -371,7 +365,7 @@ test_hw_mon_poll(void **state __attribute__((unused)))
         ret = hw_mon_poll(&group, PQOS_MON_EVENT_TMEM_BW);
         assert_int_equal(ret, PQOS_RETVAL_OK);
 
-        ret = hw_mon_poll(&group, (enum pqos_mon_event) - 1);
+        ret = hw_mon_poll(&group, (enum pqos_mon_event)0xFFFFFFFF);
         assert_int_equal(ret, PQOS_RETVAL_PARAM);
 }
 
