@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,16 +30,8 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
-#include "test.h"
-
 #include "resctrl_schemata.h"
+#include "test.h"
 
 static const unsigned _buffer_size = 1024;
 static char _buffer[1024];
@@ -61,6 +53,7 @@ __wrap_fread(void *ptr,
              FILE *stream __attribute__((unused)))
 {
         const char *data = mock_ptr_type(char *);
+
         if (data == NULL)
                 return 0;
 
@@ -73,6 +66,7 @@ char *
 __wrap_fgets(char *s, int n, FILE *stream __attribute__((unused)))
 {
         const char *data = mock_ptr_type(char *);
+
         if (data == NULL)
                 return NULL;
 
