@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,12 +30,10 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
 #include "mock_cap.h"
 
+#include "mock_test.h"
+
 int
 __wrap__pqos_check_init(const int expect)
 {
@@ -56,14 +54,16 @@ __wrap__pqos_api_unlock(void)
         function_called();
 }
 
-void
-__wrap__pqos_cap_get(const struct pqos_cap **cap,
-                     const struct pqos_cpuinfo **cpu)
+const struct pqos_cap *
+__wrap__pqos_get_cap(void)
 {
-        if (cap != NULL)
-                *cap = mock_ptr_type(struct pqos_cap *);
-        if (cpu != NULL)
-                *cpu = mock_ptr_type(struct pqos_cpuinfo *);
+        return mock_ptr_type(const struct pqos_cap *);
+}
+
+const struct pqos_cpuinfo *
+__wrap__pqos_get_cpu(void)
+{
+        return mock_ptr_type(const struct pqos_cpuinfo *);
 }
 
 void
