@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,12 +30,10 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
 #include "mock_monitoring.h"
 
+#include "mock_test.h"
+
 int
 __wrap_pqos_mon_poll_events(struct pqos_mon_data *group)
 {
@@ -53,4 +51,4 @@ __wrap_resctrl_mon_active(unsigned *monitoring_status)
                 *monitoring_status = mock_type(int);
 
         return ret;
-}
\ No newline at end of file
+}
