@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2022 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -29,15 +29,12 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-#include <string.h>
-
 #include "mock_resctrl.h"
 
+#include "mock_test.h"
+
+#include <string.h>
+
 int
 __wrap_resctrl_cpumask_write(FILE *fd, const struct resctrl_cpumask *mask)
 {
@@ -99,4 +96,4 @@ int
 __wrap_resctrl_lock_release(void)
 {
         return mock_type(int);
-}
\ No newline at end of file
+}
